#!/bin/bash
# Script preparing visual QC of subfields
# by collecting necessary raw files into
# a subfolder within mri.
# PS 2016
# PS 2019 adaptation for combined hippocampal-amygdala-image

subject_folder=/data3/ex2
FS_bin=$FREESURFER_HOME/bin
cd ${subject_folder}

for subject_id in $(cat /home/philipp/listsubjects.txt); do
    
    dir_mri=${subject_folder}/${subject_id}/mri
    dir_assembly=${subject_folder}/${subject_id}/mri/assembly
    mkdir -p ${dir_assembly}
    echo =================
    echo WORKING ON ${subject_id}
    echo =================
    rm ${dir_assembly}/*mgz ${dir_assembly}/*nii ${dir_assembly}/*nii.gz
    
    # copy relevant files to assembly folder
    cp ${dir_mri}/lh.hippoAmygLabels-T1.v21.FS60.mgz ${dir_mri}/assembly/left_discreteLabels.mgz
    cp ${dir_mri}/rh.hippoAmygLabels-T1.v21.FS60.mgz ${dir_mri}/assembly/right_discreteLabels.mgz
    cp ${dir_mri}/nu.mgz ${dir_mri}/assembly
    cp ${dir_mri}/aparc+aseg.mgz ${dir_mri}/assembly/aparc+aseg.mgz
    
    # convert and resample all needed files
    cd ${dir_assembly}
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RSA left_discreteLabels.mgz left_discreteLabels.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RSA right_discreteLabels.mgz right_discreteLabels.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RSA aparc+aseg.mgz aparc+aseg.nii.gz
    
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RSA --reslice_like left_discreteLabels.mgz nu.mgz nu_left.nii.gz # note RSA
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RSA --reslice_like right_discreteLabels.mgz nu.mgz nu_right.nii.gz # note RSA
    
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RSA --reslice_like left_discreteLabels.mgz aparc+aseg.mgz aparc+aseg_highres_L.nii.gz
    ${FS_bin}/mri_convert --resample_type nearest --out_orientation RSA --reslice_like right_discreteLabels.mgz aparc+aseg.mgz aparc+aseg_highres_R.nii.gz
    
    # and unzip them to go sure they can be read in later by the load_nii command
    gunzip *.nii.gz
    
done
